@@ -24,27 +24,27 @@ test_that("backup/rotate happy path", {
 
   # no backup because dry run
   expect_message(backup(tf, dry_run = TRUE), "dry_run")
-  expect_identical(bq$n_backups, 0L)
+  expect_identical(bq$n, 0L)
 
   # not rotating because file is to small
   backup(tf, size = 1e6)
-  expect_identical(bq$n_backups, 0L)
+  expect_identical(bq$n, 0L)
 
   # backup
   backup(tf, size = 1)
-  expect_identical(bq$n_backups, 1L)
+  expect_identical(bq$n, 1L)
 
   # backup (zip)
   backup(tf, compression = TRUE)
-  expect_identical(bq$n_backups, 2L)
-  expect_identical(tools::file_ext(bq$backups$path[[1]]), "zip")
+  expect_identical(bq$n, 2L)
+  expect_identical(tools::file_ext(bq$files$path[[1]]), "zip")
 
   # rotating
   rotate(tf, compression = FALSE)
-  expect_identical(bq$n_backups, 3L)
+  expect_identical(bq$n, 3L)
   expect_equal(file.size(tf), 0)
-  expect_equal(file.size(bq$backups$path[[1]]), tf_size)
-  expect_equal(bq$backups$sfx, as.character(1:3))
+  expect_equal(file.size(bq$files$path[[1]]), tf_size)
+  expect_equal(bq$files$sfx, as.character(1:3))
 
   bq$prune(0)
   file.remove(tf)
@@ -64,19 +64,19 @@ test_that("backup/rotate works to different directory", {
 
   # dry run does nothing
   snap <- fileSnapshot(bu_dir)
-  expect_message(backup(tf, backup_dir = bu_dir, dry_run = TRUE))
+  expect_message(backup(tf, dir = bu_dir, dry_run = TRUE))
   expect_snapshot_unchanged(snap)
 
   # create backup in different dir
-  backup(tf, backup_dir = bu_dir)
+  backup(tf, dir = bu_dir)
   expect_identical(
     readLines(tf),
     readLines(file.path(dirname(tf), "backups", "test.1.log"))
   )
 
-  expect_identical(n_backups(tf, backup_dir = bu_dir), 1L)
-  prune_backups(tf, 0, backup_dir = bu_dir)
-  expect_identical(n_backups(tf, backup_dir = bu_dir), 0L)
+  expect_identical(n_backups(tf, dir = bu_dir), 1L)
+  prune_backups(tf, 0, dir = bu_dir)
+  expect_identical(n_backups(tf, dir = bu_dir), 0L)
   expect_length(list.files(bu_dir), 0)
 })
 
@@ -123,3 +123,36 @@ test_that("backup/rotate dry_run", {
 
   expect_snapshot_unchanged(snap)
 })
+
+
+
+
+test_that("BackupQueueIndex: $prune_identical works", {
+  tf <- file.path(td, "test")
+
+  saveRDS(iris, tf)
+  iris_md5 <- tools::md5sum(tf)
+  bq <- BackupQueueIndex$new(tf)
+  on.exit({
+    bq$prune(0)
+    unlink(tf)
+  })
+  backup(tf)
+  backup(tf)
+  rotate(tf)
+
+  saveRDS(cars, tf)
+  cars_md5 <- tools::md5sum(tf)
+  backup(tf)
+  saveRDS(cars, tf)
+  rotate(tf)
+
+  saveRDS(iris, tf)
+
+  prune_identical_backups(tf)
+
+  expect_identical(
+    unname(tools::md5sum(bq$files$path)),
+    unname(c(cars_md5, iris_md5))
+  )
+})
